"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const { performance } = typeof window !== 'undefined' ? window : require('perf_hooks');
const round = (n, d) => +n.toFixed(d);
const wrapMultiplier = (m) => (n) => n * m;
const keys = {
    s: wrapMultiplier(0.001),
    ms: wrapMultiplier(1),
    us: wrapMultiplier(1000),
};
function ElapsingTime() {
    let time = 0;
    let count = 0;
    let startedTime = 0;
    let cachedTime = false;
    const res = {};
    res.start = () => {
        if (cachedTime) {
            res.reset();
            cachedTime = false;
        }
        startedTime = performance.now();
        count++;
    };
    res.stop = (withReset = false) => {
        if (startedTime) {
            time += performance.now() - startedTime;
            startedTime = 0;
        }
        if (withReset) {
            cachedTime = true;
        }
    };
    res.reset = () => {
        time = count = startedTime = 0;
    };
    function get(key, avg = false) {
        const st = startedTime && performance.now() - startedTime;
        const t = (time + st) / (avg && count || 1);
        return round(keys[key](t), 3);
    }
    for (const key of Object.keys(keys)) {
        Object.defineProperty(res, key, { get: () => get(key), enumerable: true });
    }
    res.avg = {};
    for (const key of Object.keys(keys)) {
        Object.defineProperty(res.avg, key, { get: () => get(key, true), enumerable: true });
    }
    function printWrapper(obj, key) {
        return (label) => console.info(`${label || 'Time'}: ${obj[key]} ${key}`);
    }
    for (const key of Object.keys(keys)) {
        res[`${key}Print`] = printWrapper(res, key);
        res.avg[`${key}Print`] = printWrapper(res.avg, key);
    }
    return res;
}
exports.default = ElapsingTime;
if (typeof exports.default === 'function') {
    module.exports = exports.default;
    Object.assign(module.exports, exports);
}
